@@ -4,38 +4,53 @@ import terrascript.core as core
 
 
 @core.schema
-class S3(core.Schema):
+class Lambda(core.Schema):
 
-    bucket_arn: Union[str, core.StringOut] = core.attr(str)
-
-    file_key: Union[str, core.StringOut] = core.attr(str)
+    resource_arn: Union[str, core.StringOut] = core.attr(str)
 
     role_arn: Union[str, core.StringOut] = core.attr(str)
 
     def __init__(
         self,
         *,
-        bucket_arn: Union[str, core.StringOut],
-        file_key: Union[str, core.StringOut],
+        resource_arn: Union[str, core.StringOut],
         role_arn: Union[str, core.StringOut],
     ):
         super().__init__(
-            args=S3.Args(
-                bucket_arn=bucket_arn,
-                file_key=file_key,
+            args=Lambda.Args(
+                resource_arn=resource_arn,
                 role_arn=role_arn,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        bucket_arn: Union[str, core.StringOut] = core.arg()
-
-        file_key: Union[str, core.StringOut] = core.arg()
+        resource_arn: Union[str, core.StringOut] = core.arg()
 
         role_arn: Union[str, core.StringOut] = core.arg()
 
 
+@core.schema
+class ProcessingConfiguration(core.Schema):
+
+    lambda_: Lambda = core.attr(Lambda, alias="lambda")
+
+    def __init__(
+        self,
+        *,
+        lambda_: Lambda,
+    ):
+        super().__init__(
+            args=ProcessingConfiguration.Args(
+                lambda_=lambda_,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        lambda_: Lambda = core.arg()
+
+
 @core.schema
 class RecordColumns(core.Schema):
 
@@ -69,27 +84,6 @@ class RecordColumns(core.Schema):
         sql_type: Union[str, core.StringOut] = core.arg()
 
 
-@core.schema
-class Json(core.Schema):
-
-    record_row_path: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        record_row_path: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=Json.Args(
-                record_row_path=record_row_path,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        record_row_path: Union[str, core.StringOut] = core.arg()
-
-
 @core.schema
 class Csv(core.Schema):
 
@@ -117,6 +111,27 @@ class Csv(core.Schema):
         record_row_delimiter: Union[str, core.StringOut] = core.arg()
 
 
+@core.schema
+class Json(core.Schema):
+
+    record_row_path: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        record_row_path: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=Json.Args(
+                record_row_path=record_row_path,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        record_row_path: Union[str, core.StringOut] = core.arg()
+
+
 @core.schema
 class MappingParameters(core.Schema):
 
@@ -172,7 +187,7 @@ class RecordFormat(core.Schema):
 
 
 @core.schema
-class ReferenceDataSourcesSchema(core.Schema):
+class InputsSchema(core.Schema):
 
     record_columns: Union[List[RecordColumns], core.ArrayOut[RecordColumns]] = core.attr(
         RecordColumns, kind=core.Kind.array
@@ -190,7 +205,7 @@ class ReferenceDataSourcesSchema(core.Schema):
         record_encoding: Optional[Union[str, core.StringOut]] = None,
     ):
         super().__init__(
-            args=ReferenceDataSourcesSchema.Args(
+            args=InputsSchema.Args(
                 record_columns=record_columns,
                 record_format=record_format,
                 record_encoding=record_encoding,
@@ -206,176 +221,6 @@ class ReferenceDataSourcesSchema(core.Schema):
         record_format: RecordFormat = core.arg()
 
 
-@core.schema
-class ReferenceDataSources(core.Schema):
-
-    id: Union[str, core.StringOut] = core.attr(str, computed=True)
-
-    s3: S3 = core.attr(S3)
-
-    schema: ReferenceDataSourcesSchema = core.attr(ReferenceDataSourcesSchema)
-
-    table_name: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        id: Union[str, core.StringOut],
-        s3: S3,
-        schema: ReferenceDataSourcesSchema,
-        table_name: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=ReferenceDataSources.Args(
-                id=id,
-                s3=s3,
-                schema=schema,
-                table_name=table_name,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        id: Union[str, core.StringOut] = core.arg()
-
-        s3: S3 = core.arg()
-
-        schema: ReferenceDataSourcesSchema = core.arg()
-
-        table_name: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class CloudwatchLoggingOptions(core.Schema):
-
-    id: Union[str, core.StringOut] = core.attr(str, computed=True)
-
-    log_stream_arn: Union[str, core.StringOut] = core.attr(str)
-
-    role_arn: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        id: Union[str, core.StringOut],
-        log_stream_arn: Union[str, core.StringOut],
-        role_arn: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=CloudwatchLoggingOptions.Args(
-                id=id,
-                log_stream_arn=log_stream_arn,
-                role_arn=role_arn,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        id: Union[str, core.StringOut] = core.arg()
-
-        log_stream_arn: Union[str, core.StringOut] = core.arg()
-
-        role_arn: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class StartingPositionConfiguration(core.Schema):
-
-    starting_position: Optional[Union[str, core.StringOut]] = core.attr(
-        str, default=None, computed=True
-    )
-
-    def __init__(
-        self,
-        *,
-        starting_position: Optional[Union[str, core.StringOut]] = None,
-    ):
-        super().__init__(
-            args=StartingPositionConfiguration.Args(
-                starting_position=starting_position,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        starting_position: Optional[Union[str, core.StringOut]] = core.arg(default=None)
-
-
-@core.schema
-class KinesisStream(core.Schema):
-
-    resource_arn: Union[str, core.StringOut] = core.attr(str)
-
-    role_arn: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        resource_arn: Union[str, core.StringOut],
-        role_arn: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=KinesisStream.Args(
-                resource_arn=resource_arn,
-                role_arn=role_arn,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        resource_arn: Union[str, core.StringOut] = core.arg()
-
-        role_arn: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class Lambda(core.Schema):
-
-    resource_arn: Union[str, core.StringOut] = core.attr(str)
-
-    role_arn: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        resource_arn: Union[str, core.StringOut],
-        role_arn: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=Lambda.Args(
-                resource_arn=resource_arn,
-                role_arn=role_arn,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        resource_arn: Union[str, core.StringOut] = core.arg()
-
-        role_arn: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class ProcessingConfiguration(core.Schema):
-
-    lambda_: Lambda = core.attr(Lambda, alias="lambda")
-
-    def __init__(
-        self,
-        *,
-        lambda_: Lambda,
-    ):
-        super().__init__(
-            args=ProcessingConfiguration.Args(
-                lambda_=lambda_,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        lambda_: Lambda = core.arg()
-
-
 @core.schema
 class KinesisFirehose(core.Schema):
 
@@ -403,6 +248,33 @@ class KinesisFirehose(core.Schema):
         role_arn: Union[str, core.StringOut] = core.arg()
 
 
+@core.schema
+class KinesisStream(core.Schema):
+
+    resource_arn: Union[str, core.StringOut] = core.attr(str)
+
+    role_arn: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        resource_arn: Union[str, core.StringOut],
+        role_arn: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=KinesisStream.Args(
+                resource_arn=resource_arn,
+                role_arn=role_arn,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        resource_arn: Union[str, core.StringOut] = core.arg()
+
+        role_arn: Union[str, core.StringOut] = core.arg()
+
+
 @core.schema
 class Parallelism(core.Schema):
 
@@ -424,6 +296,29 @@ class Parallelism(core.Schema):
         count: Optional[Union[int, core.IntOut]] = core.arg(default=None)
 
 
+@core.schema
+class StartingPositionConfiguration(core.Schema):
+
+    starting_position: Optional[Union[str, core.StringOut]] = core.attr(
+        str, default=None, computed=True
+    )
+
+    def __init__(
+        self,
+        *,
+        starting_position: Optional[Union[str, core.StringOut]] = None,
+    ):
+        super().__init__(
+            args=StartingPositionConfiguration.Args(
+                starting_position=starting_position,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        starting_position: Optional[Union[str, core.StringOut]] = core.arg(default=None)
+
+
 @core.schema
 class Inputs(core.Schema):
 
@@ -441,7 +336,7 @@ class Inputs(core.Schema):
         ProcessingConfiguration, default=None
     )
 
-    schema: ReferenceDataSourcesSchema = core.attr(ReferenceDataSourcesSchema)
+    schema: InputsSchema = core.attr(InputsSchema)
 
     starting_position_configuration: Optional[
         Union[List[StartingPositionConfiguration], core.ArrayOut[StartingPositionConfiguration]]
@@ -456,7 +351,7 @@ class Inputs(core.Schema):
         *,
         id: Union[str, core.StringOut],
         name_prefix: Union[str, core.StringOut],
-        schema: ReferenceDataSourcesSchema,
+        schema: InputsSchema,
         stream_names: Union[List[str], core.ArrayOut[core.StringOut]],
         kinesis_firehose: Optional[KinesisFirehose] = None,
         kinesis_stream: Optional[KinesisStream] = None,
@@ -494,7 +389,7 @@ class Inputs(core.Schema):
 
         processing_configuration: Optional[ProcessingConfiguration] = core.arg(default=None)
 
-        schema: ReferenceDataSourcesSchema = core.arg()
+        schema: InputsSchema = core.arg()
 
         starting_position_configuration: Optional[
             Union[List[StartingPositionConfiguration], core.ArrayOut[StartingPositionConfiguration]]
@@ -503,6 +398,39 @@ class Inputs(core.Schema):
         stream_names: Union[List[str], core.ArrayOut[core.StringOut]] = core.arg()
 
 
+@core.schema
+class CloudwatchLoggingOptions(core.Schema):
+
+    id: Union[str, core.StringOut] = core.attr(str, computed=True)
+
+    log_stream_arn: Union[str, core.StringOut] = core.attr(str)
+
+    role_arn: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        id: Union[str, core.StringOut],
+        log_stream_arn: Union[str, core.StringOut],
+        role_arn: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=CloudwatchLoggingOptions.Args(
+                id=id,
+                log_stream_arn=log_stream_arn,
+                role_arn=role_arn,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        id: Union[str, core.StringOut] = core.arg()
+
+        log_stream_arn: Union[str, core.StringOut] = core.arg()
+
+        role_arn: Union[str, core.StringOut] = core.arg()
+
+
 @core.schema
 class OutputsSchema(core.Schema):
 
@@ -575,6 +503,78 @@ class Outputs(core.Schema):
         schema: OutputsSchema = core.arg()
 
 
+@core.schema
+class S3(core.Schema):
+
+    bucket_arn: Union[str, core.StringOut] = core.attr(str)
+
+    file_key: Union[str, core.StringOut] = core.attr(str)
+
+    role_arn: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        bucket_arn: Union[str, core.StringOut],
+        file_key: Union[str, core.StringOut],
+        role_arn: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=S3.Args(
+                bucket_arn=bucket_arn,
+                file_key=file_key,
+                role_arn=role_arn,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        bucket_arn: Union[str, core.StringOut] = core.arg()
+
+        file_key: Union[str, core.StringOut] = core.arg()
+
+        role_arn: Union[str, core.StringOut] = core.arg()
+
+
+@core.schema
+class ReferenceDataSources(core.Schema):
+
+    id: Union[str, core.StringOut] = core.attr(str, computed=True)
+
+    s3: S3 = core.attr(S3)
+
+    schema: InputsSchema = core.attr(InputsSchema)
+
+    table_name: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        id: Union[str, core.StringOut],
+        s3: S3,
+        schema: InputsSchema,
+        table_name: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=ReferenceDataSources.Args(
+                id=id,
+                s3=s3,
+                schema=schema,
+                table_name=table_name,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        id: Union[str, core.StringOut] = core.arg()
+
+        s3: S3 = core.arg()
+
+        schema: InputsSchema = core.arg()
+
+        table_name: Union[str, core.StringOut] = core.arg()
+
+
 @core.resource(type="aws_kinesis_analytics_application", namespace="aws_kinesis_analytics")
 class Application(core.Resource):
 
