@@ -4,36 +4,219 @@ import terrascript.core as core
 
 
 @core.schema
-class VisibilityConfig(core.Schema):
+class InsertHeader(core.Schema):
 
-    cloudwatch_metrics_enabled: Union[bool, core.BoolOut] = core.attr(bool)
+    name: Union[str, core.StringOut] = core.attr(str)
 
-    metric_name: Union[str, core.StringOut] = core.attr(str)
-
-    sampled_requests_enabled: Union[bool, core.BoolOut] = core.attr(bool)
+    value: Union[str, core.StringOut] = core.attr(str)
 
     def __init__(
         self,
         *,
-        cloudwatch_metrics_enabled: Union[bool, core.BoolOut],
-        metric_name: Union[str, core.StringOut],
-        sampled_requests_enabled: Union[bool, core.BoolOut],
+        name: Union[str, core.StringOut],
+        value: Union[str, core.StringOut],
     ):
         super().__init__(
-            args=VisibilityConfig.Args(
-                cloudwatch_metrics_enabled=cloudwatch_metrics_enabled,
-                metric_name=metric_name,
-                sampled_requests_enabled=sampled_requests_enabled,
+            args=InsertHeader.Args(
+                name=name,
+                value=value,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        cloudwatch_metrics_enabled: Union[bool, core.BoolOut] = core.arg()
+        name: Union[str, core.StringOut] = core.arg()
 
-        metric_name: Union[str, core.StringOut] = core.arg()
+        value: Union[str, core.StringOut] = core.arg()
 
-        sampled_requests_enabled: Union[bool, core.BoolOut] = core.arg()
+
+@core.schema
+class CustomRequestHandling(core.Schema):
+
+    insert_header: Union[List[InsertHeader], core.ArrayOut[InsertHeader]] = core.attr(
+        InsertHeader, kind=core.Kind.array
+    )
+
+    def __init__(
+        self,
+        *,
+        insert_header: Union[List[InsertHeader], core.ArrayOut[InsertHeader]],
+    ):
+        super().__init__(
+            args=CustomRequestHandling.Args(
+                insert_header=insert_header,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        insert_header: Union[List[InsertHeader], core.ArrayOut[InsertHeader]] = core.arg()
+
+
+@core.schema
+class Allow(core.Schema):
+
+    custom_request_handling: Optional[CustomRequestHandling] = core.attr(
+        CustomRequestHandling, default=None
+    )
+
+    def __init__(
+        self,
+        *,
+        custom_request_handling: Optional[CustomRequestHandling] = None,
+    ):
+        super().__init__(
+            args=Allow.Args(
+                custom_request_handling=custom_request_handling,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        custom_request_handling: Optional[CustomRequestHandling] = core.arg(default=None)
+
+
+@core.schema
+class ResponseHeader(core.Schema):
+
+    name: Union[str, core.StringOut] = core.attr(str)
+
+    value: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        name: Union[str, core.StringOut],
+        value: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=ResponseHeader.Args(
+                name=name,
+                value=value,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        name: Union[str, core.StringOut] = core.arg()
+
+        value: Union[str, core.StringOut] = core.arg()
+
+
+@core.schema
+class CustomResponse(core.Schema):
+
+    custom_response_body_key: Optional[Union[str, core.StringOut]] = core.attr(str, default=None)
+
+    response_code: Union[int, core.IntOut] = core.attr(int)
+
+    response_header: Optional[
+        Union[List[ResponseHeader], core.ArrayOut[ResponseHeader]]
+    ] = core.attr(ResponseHeader, default=None, kind=core.Kind.array)
+
+    def __init__(
+        self,
+        *,
+        response_code: Union[int, core.IntOut],
+        custom_response_body_key: Optional[Union[str, core.StringOut]] = None,
+        response_header: Optional[
+            Union[List[ResponseHeader], core.ArrayOut[ResponseHeader]]
+        ] = None,
+    ):
+        super().__init__(
+            args=CustomResponse.Args(
+                response_code=response_code,
+                custom_response_body_key=custom_response_body_key,
+                response_header=response_header,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        custom_response_body_key: Optional[Union[str, core.StringOut]] = core.arg(default=None)
+
+        response_code: Union[int, core.IntOut] = core.arg()
+
+        response_header: Optional[
+            Union[List[ResponseHeader], core.ArrayOut[ResponseHeader]]
+        ] = core.arg(default=None)
+
+
+@core.schema
+class Block(core.Schema):
+
+    custom_response: Optional[CustomResponse] = core.attr(CustomResponse, default=None)
+
+    def __init__(
+        self,
+        *,
+        custom_response: Optional[CustomResponse] = None,
+    ):
+        super().__init__(
+            args=Block.Args(
+                custom_response=custom_response,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        custom_response: Optional[CustomResponse] = core.arg(default=None)
+
+
+@core.schema
+class Count(core.Schema):
+
+    custom_request_handling: Optional[CustomRequestHandling] = core.attr(
+        CustomRequestHandling, default=None
+    )
+
+    def __init__(
+        self,
+        *,
+        custom_request_handling: Optional[CustomRequestHandling] = None,
+    ):
+        super().__init__(
+            args=Count.Args(
+                custom_request_handling=custom_request_handling,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        custom_request_handling: Optional[CustomRequestHandling] = core.arg(default=None)
+
+
+@core.schema
+class Action(core.Schema):
+
+    allow: Optional[Allow] = core.attr(Allow, default=None)
+
+    block: Optional[Block] = core.attr(Block, default=None)
+
+    count: Optional[Count] = core.attr(Count, default=None)
+
+    def __init__(
+        self,
+        *,
+        allow: Optional[Allow] = None,
+        block: Optional[Block] = None,
+        count: Optional[Count] = None,
+    ):
+        super().__init__(
+            args=Action.Args(
+                allow=allow,
+                block=block,
+                count=count,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        allow: Optional[Allow] = core.arg(default=None)
+
+        block: Optional[Block] = core.arg(default=None)
+
+        count: Optional[Count] = core.arg(default=None)
 
 
 @core.schema
@@ -58,59 +241,60 @@ class RuleLabel(core.Schema):
 
 
 @core.schema
-class ForwardedIpConfig(core.Schema):
+class LabelMatchStatement(core.Schema):
 
-    fallback_behavior: Union[str, core.StringOut] = core.attr(str)
+    key: Union[str, core.StringOut] = core.attr(str)
 
-    header_name: Union[str, core.StringOut] = core.attr(str)
+    scope: Union[str, core.StringOut] = core.attr(str)
 
     def __init__(
         self,
         *,
-        fallback_behavior: Union[str, core.StringOut],
-        header_name: Union[str, core.StringOut],
+        key: Union[str, core.StringOut],
+        scope: Union[str, core.StringOut],
     ):
         super().__init__(
-            args=ForwardedIpConfig.Args(
-                fallback_behavior=fallback_behavior,
-                header_name=header_name,
+            args=LabelMatchStatement.Args(
+                key=key,
+                scope=scope,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        fallback_behavior: Union[str, core.StringOut] = core.arg()
+        key: Union[str, core.StringOut] = core.arg()
 
-        header_name: Union[str, core.StringOut] = core.arg()
+        scope: Union[str, core.StringOut] = core.arg()
 
 
 @core.schema
-class GeoMatchStatement(core.Schema):
+class SingleQueryArgument(core.Schema):
 
-    country_codes: Union[List[str], core.ArrayOut[core.StringOut]] = core.attr(
-        str, kind=core.Kind.array
-    )
-
-    forwarded_ip_config: Optional[ForwardedIpConfig] = core.attr(ForwardedIpConfig, default=None)
+    name: Union[str, core.StringOut] = core.attr(str)
 
     def __init__(
         self,
         *,
-        country_codes: Union[List[str], core.ArrayOut[core.StringOut]],
-        forwarded_ip_config: Optional[ForwardedIpConfig] = None,
+        name: Union[str, core.StringOut],
     ):
         super().__init__(
-            args=GeoMatchStatement.Args(
-                country_codes=country_codes,
-                forwarded_ip_config=forwarded_ip_config,
+            args=SingleQueryArgument.Args(
+                name=name,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        country_codes: Union[List[str], core.ArrayOut[core.StringOut]] = core.arg()
+        name: Union[str, core.StringOut] = core.arg()
 
-        forwarded_ip_config: Optional[ForwardedIpConfig] = core.arg(default=None)
+
+@core.schema
+class UriPath(core.Schema):
+    ...
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        ...
 
 
 @core.schema
@@ -170,36 +354,6 @@ class SingleHeader(core.Schema):
         name: Union[str, core.StringOut] = core.arg()
 
 
-@core.schema
-class SingleQueryArgument(core.Schema):
-
-    name: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        name: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=SingleQueryArgument.Args(
-                name=name,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        name: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class UriPath(core.Schema):
-    ...
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        ...
-
-
 @core.schema
 class FieldToMatch(core.Schema):
 
@@ -323,6 +477,136 @@ class RegexPatternSetReferenceStatement(core.Schema):
         ] = core.arg()
 
 
+@core.schema
+class ForwardedIpConfig(core.Schema):
+
+    fallback_behavior: Union[str, core.StringOut] = core.attr(str)
+
+    header_name: Union[str, core.StringOut] = core.attr(str)
+
+    def __init__(
+        self,
+        *,
+        fallback_behavior: Union[str, core.StringOut],
+        header_name: Union[str, core.StringOut],
+    ):
+        super().__init__(
+            args=ForwardedIpConfig.Args(
+                fallback_behavior=fallback_behavior,
+                header_name=header_name,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        fallback_behavior: Union[str, core.StringOut] = core.arg()
+
+        header_name: Union[str, core.StringOut] = core.arg()
+
+
+@core.schema
+class GeoMatchStatement(core.Schema):
+
+    country_codes: Union[List[str], core.ArrayOut[core.StringOut]] = core.attr(
+        str, kind=core.Kind.array
+    )
+
+    forwarded_ip_config: Optional[ForwardedIpConfig] = core.attr(ForwardedIpConfig, default=None)
+
+    def __init__(
+        self,
+        *,
+        country_codes: Union[List[str], core.ArrayOut[core.StringOut]],
+        forwarded_ip_config: Optional[ForwardedIpConfig] = None,
+    ):
+        super().__init__(
+            args=GeoMatchStatement.Args(
+                country_codes=country_codes,
+                forwarded_ip_config=forwarded_ip_config,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        country_codes: Union[List[str], core.ArrayOut[core.StringOut]] = core.arg()
+
+        forwarded_ip_config: Optional[ForwardedIpConfig] = core.arg(default=None)
+
+
+@core.schema
+class SizeConstraintStatement(core.Schema):
+
+    comparison_operator: Union[str, core.StringOut] = core.attr(str)
+
+    field_to_match: Optional[FieldToMatch] = core.attr(FieldToMatch, default=None)
+
+    size: Union[int, core.IntOut] = core.attr(int)
+
+    text_transformation: Union[
+        List[TextTransformation], core.ArrayOut[TextTransformation]
+    ] = core.attr(TextTransformation, kind=core.Kind.array)
+
+    def __init__(
+        self,
+        *,
+        comparison_operator: Union[str, core.StringOut],
+        size: Union[int, core.IntOut],
+        text_transformation: Union[List[TextTransformation], core.ArrayOut[TextTransformation]],
+        field_to_match: Optional[FieldToMatch] = None,
+    ):
+        super().__init__(
+            args=SizeConstraintStatement.Args(
+                comparison_operator=comparison_operator,
+                size=size,
+                text_transformation=text_transformation,
+                field_to_match=field_to_match,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        comparison_operator: Union[str, core.StringOut] = core.arg()
+
+        field_to_match: Optional[FieldToMatch] = core.arg(default=None)
+
+        size: Union[int, core.IntOut] = core.arg()
+
+        text_transformation: Union[
+            List[TextTransformation], core.ArrayOut[TextTransformation]
+        ] = core.arg()
+
+
+@core.schema
+class XssMatchStatement(core.Schema):
+
+    field_to_match: Optional[FieldToMatch] = core.attr(FieldToMatch, default=None)
+
+    text_transformation: Union[
+        List[TextTransformation], core.ArrayOut[TextTransformation]
+    ] = core.attr(TextTransformation, kind=core.Kind.array)
+
+    def __init__(
+        self,
+        *,
+        text_transformation: Union[List[TextTransformation], core.ArrayOut[TextTransformation]],
+        field_to_match: Optional[FieldToMatch] = None,
+    ):
+        super().__init__(
+            args=XssMatchStatement.Args(
+                text_transformation=text_transformation,
+                field_to_match=field_to_match,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        field_to_match: Optional[FieldToMatch] = core.arg(default=None)
+
+        text_transformation: Union[
+            List[TextTransformation], core.ArrayOut[TextTransformation]
+        ] = core.arg()
+
+
 @core.schema
 class IpSetForwardedIpConfig(core.Schema):
 
@@ -385,76 +669,6 @@ class IpSetReferenceStatement(core.Schema):
         ip_set_forwarded_ip_config: Optional[IpSetForwardedIpConfig] = core.arg(default=None)
 
 
-@core.schema
-class LabelMatchStatement(core.Schema):
-
-    key: Union[str, core.StringOut] = core.attr(str)
-
-    scope: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        key: Union[str, core.StringOut],
-        scope: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=LabelMatchStatement.Args(
-                key=key,
-                scope=scope,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        key: Union[str, core.StringOut] = core.arg()
-
-        scope: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class SizeConstraintStatement(core.Schema):
-
-    comparison_operator: Union[str, core.StringOut] = core.attr(str)
-
-    field_to_match: Optional[FieldToMatch] = core.attr(FieldToMatch, default=None)
-
-    size: Union[int, core.IntOut] = core.attr(int)
-
-    text_transformation: Union[
-        List[TextTransformation], core.ArrayOut[TextTransformation]
-    ] = core.attr(TextTransformation, kind=core.Kind.array)
-
-    def __init__(
-        self,
-        *,
-        comparison_operator: Union[str, core.StringOut],
-        size: Union[int, core.IntOut],
-        text_transformation: Union[List[TextTransformation], core.ArrayOut[TextTransformation]],
-        field_to_match: Optional[FieldToMatch] = None,
-    ):
-        super().__init__(
-            args=SizeConstraintStatement.Args(
-                comparison_operator=comparison_operator,
-                size=size,
-                text_transformation=text_transformation,
-                field_to_match=field_to_match,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        comparison_operator: Union[str, core.StringOut] = core.arg()
-
-        field_to_match: Optional[FieldToMatch] = core.arg(default=None)
-
-        size: Union[int, core.IntOut] = core.arg()
-
-        text_transformation: Union[
-            List[TextTransformation], core.ArrayOut[TextTransformation]
-        ] = core.arg()
-
-
 @core.schema
 class SqliMatchStatement(core.Schema):
 
@@ -486,37 +700,6 @@ class SqliMatchStatement(core.Schema):
         ] = core.arg()
 
 
-@core.schema
-class XssMatchStatement(core.Schema):
-
-    field_to_match: Optional[FieldToMatch] = core.attr(FieldToMatch, default=None)
-
-    text_transformation: Union[
-        List[TextTransformation], core.ArrayOut[TextTransformation]
-    ] = core.attr(TextTransformation, kind=core.Kind.array)
-
-    def __init__(
-        self,
-        *,
-        text_transformation: Union[List[TextTransformation], core.ArrayOut[TextTransformation]],
-        field_to_match: Optional[FieldToMatch] = None,
-    ):
-        super().__init__(
-            args=XssMatchStatement.Args(
-                text_transformation=text_transformation,
-                field_to_match=field_to_match,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        field_to_match: Optional[FieldToMatch] = core.arg(default=None)
-
-        text_transformation: Union[
-            List[TextTransformation], core.ArrayOut[TextTransformation]
-        ] = core.arg()
-
-
 @core.schema
 class ByteMatchStatement(core.Schema):
 
@@ -561,7 +744,7 @@ class ByteMatchStatement(core.Schema):
 
 
 @core.schema
-class RuleStatementNotStatementStatementOrStatementStatement(core.Schema):
+class RuleStatementNotStatementStatementAndStatementStatement(core.Schema):
 
     byte_match_statement: Optional[ByteMatchStatement] = core.attr(ByteMatchStatement, default=None)
 
@@ -600,7 +783,7 @@ class RuleStatementNotStatementStatementOrStatementStatement(core.Schema):
         xss_match_statement: Optional[XssMatchStatement] = None,
     ):
         super().__init__(
-            args=RuleStatementNotStatementStatementOrStatementStatement.Args(
+            args=RuleStatementNotStatementStatementAndStatementStatement.Args(
                 byte_match_statement=byte_match_statement,
                 geo_match_statement=geo_match_statement,
                 ip_set_reference_statement=ip_set_reference_statement,
@@ -633,50 +816,20 @@ class RuleStatementNotStatementStatementOrStatementStatement(core.Schema):
         xss_match_statement: Optional[XssMatchStatement] = core.arg(default=None)
 
 
-@core.schema
-class RuleStatementNotStatementStatementOrStatement(core.Schema):
-
-    statement: Union[
-        List[RuleStatementNotStatementStatementOrStatementStatement],
-        core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
-    ] = core.attr(RuleStatementNotStatementStatementOrStatementStatement, kind=core.Kind.array)
-
-    def __init__(
-        self,
-        *,
-        statement: Union[
-            List[RuleStatementNotStatementStatementOrStatementStatement],
-            core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
-        ],
-    ):
-        super().__init__(
-            args=RuleStatementNotStatementStatementOrStatement.Args(
-                statement=statement,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        statement: Union[
-            List[RuleStatementNotStatementStatementOrStatementStatement],
-            core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
-        ] = core.arg()
-
-
 @core.schema
 class RuleStatementNotStatementStatementAndStatement(core.Schema):
 
     statement: Union[
-        List[RuleStatementNotStatementStatementOrStatementStatement],
-        core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
-    ] = core.attr(RuleStatementNotStatementStatementOrStatementStatement, kind=core.Kind.array)
+        List[RuleStatementNotStatementStatementAndStatementStatement],
+        core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
+    ] = core.attr(RuleStatementNotStatementStatementAndStatementStatement, kind=core.Kind.array)
 
     def __init__(
         self,
         *,
         statement: Union[
-            List[RuleStatementNotStatementStatementOrStatementStatement],
-            core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
+            List[RuleStatementNotStatementStatementAndStatementStatement],
+            core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
         ],
     ):
         super().__init__(
@@ -688,8 +841,8 @@ class RuleStatementNotStatementStatementAndStatement(core.Schema):
     @core.schema_args
     class Args(core.SchemaArgs):
         statement: Union[
-            List[RuleStatementNotStatementStatementOrStatementStatement],
-            core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
+            List[RuleStatementNotStatementStatementAndStatementStatement],
+            core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
         ] = core.arg()
 
 
@@ -697,16 +850,16 @@ class RuleStatementNotStatementStatementAndStatement(core.Schema):
 class RuleStatementNotStatementStatementNotStatement(core.Schema):
 
     statement: Union[
-        List[RuleStatementNotStatementStatementOrStatementStatement],
-        core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
-    ] = core.attr(RuleStatementNotStatementStatementOrStatementStatement, kind=core.Kind.array)
+        List[RuleStatementNotStatementStatementAndStatementStatement],
+        core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
+    ] = core.attr(RuleStatementNotStatementStatementAndStatementStatement, kind=core.Kind.array)
 
     def __init__(
         self,
         *,
         statement: Union[
-            List[RuleStatementNotStatementStatementOrStatementStatement],
-            core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
+            List[RuleStatementNotStatementStatementAndStatementStatement],
+            core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
         ],
     ):
         super().__init__(
@@ -718,8 +871,38 @@ class RuleStatementNotStatementStatementNotStatement(core.Schema):
     @core.schema_args
     class Args(core.SchemaArgs):
         statement: Union[
-            List[RuleStatementNotStatementStatementOrStatementStatement],
-            core.ArrayOut[RuleStatementNotStatementStatementOrStatementStatement],
+            List[RuleStatementNotStatementStatementAndStatementStatement],
+            core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
+        ] = core.arg()
+
+
+@core.schema
+class RuleStatementNotStatementStatementOrStatement(core.Schema):
+
+    statement: Union[
+        List[RuleStatementNotStatementStatementAndStatementStatement],
+        core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
+    ] = core.attr(RuleStatementNotStatementStatementAndStatementStatement, kind=core.Kind.array)
+
+    def __init__(
+        self,
+        *,
+        statement: Union[
+            List[RuleStatementNotStatementStatementAndStatementStatement],
+            core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
+        ],
+    ):
+        super().__init__(
+            args=RuleStatementNotStatementStatementOrStatement.Args(
+                statement=statement,
+            ),
+        )
+
+    @core.schema_args
+    class Args(core.SchemaArgs):
+        statement: Union[
+            List[RuleStatementNotStatementStatementAndStatementStatement],
+            core.ArrayOut[RuleStatementNotStatementStatementAndStatementStatement],
         ] = core.arg()
 
 
@@ -1011,219 +1194,36 @@ class RuleStatement(core.Schema):
 
 
 @core.schema
-class InsertHeader(core.Schema):
+class VisibilityConfig(core.Schema):
 
-    name: Union[str, core.StringOut] = core.attr(str)
+    cloudwatch_metrics_enabled: Union[bool, core.BoolOut] = core.attr(bool)
 
-    value: Union[str, core.StringOut] = core.attr(str)
+    metric_name: Union[str, core.StringOut] = core.attr(str)
+
+    sampled_requests_enabled: Union[bool, core.BoolOut] = core.attr(bool)
 
     def __init__(
         self,
         *,
-        name: Union[str, core.StringOut],
-        value: Union[str, core.StringOut],
+        cloudwatch_metrics_enabled: Union[bool, core.BoolOut],
+        metric_name: Union[str, core.StringOut],
+        sampled_requests_enabled: Union[bool, core.BoolOut],
     ):
         super().__init__(
-            args=InsertHeader.Args(
-                name=name,
-                value=value,
+            args=VisibilityConfig.Args(
+                cloudwatch_metrics_enabled=cloudwatch_metrics_enabled,
+                metric_name=metric_name,
+                sampled_requests_enabled=sampled_requests_enabled,
             ),
         )
 
     @core.schema_args
     class Args(core.SchemaArgs):
-        name: Union[str, core.StringOut] = core.arg()
+        cloudwatch_metrics_enabled: Union[bool, core.BoolOut] = core.arg()
 
-        value: Union[str, core.StringOut] = core.arg()
+        metric_name: Union[str, core.StringOut] = core.arg()
 
-
-@core.schema
-class CustomRequestHandling(core.Schema):
-
-    insert_header: Union[List[InsertHeader], core.ArrayOut[InsertHeader]] = core.attr(
-        InsertHeader, kind=core.Kind.array
-    )
-
-    def __init__(
-        self,
-        *,
-        insert_header: Union[List[InsertHeader], core.ArrayOut[InsertHeader]],
-    ):
-        super().__init__(
-            args=CustomRequestHandling.Args(
-                insert_header=insert_header,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        insert_header: Union[List[InsertHeader], core.ArrayOut[InsertHeader]] = core.arg()
-
-
-@core.schema
-class Allow(core.Schema):
-
-    custom_request_handling: Optional[CustomRequestHandling] = core.attr(
-        CustomRequestHandling, default=None
-    )
-
-    def __init__(
-        self,
-        *,
-        custom_request_handling: Optional[CustomRequestHandling] = None,
-    ):
-        super().__init__(
-            args=Allow.Args(
-                custom_request_handling=custom_request_handling,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        custom_request_handling: Optional[CustomRequestHandling] = core.arg(default=None)
-
-
-@core.schema
-class ResponseHeader(core.Schema):
-
-    name: Union[str, core.StringOut] = core.attr(str)
-
-    value: Union[str, core.StringOut] = core.attr(str)
-
-    def __init__(
-        self,
-        *,
-        name: Union[str, core.StringOut],
-        value: Union[str, core.StringOut],
-    ):
-        super().__init__(
-            args=ResponseHeader.Args(
-                name=name,
-                value=value,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        name: Union[str, core.StringOut] = core.arg()
-
-        value: Union[str, core.StringOut] = core.arg()
-
-
-@core.schema
-class CustomResponse(core.Schema):
-
-    custom_response_body_key: Optional[Union[str, core.StringOut]] = core.attr(str, default=None)
-
-    response_code: Union[int, core.IntOut] = core.attr(int)
-
-    response_header: Optional[
-        Union[List[ResponseHeader], core.ArrayOut[ResponseHeader]]
-    ] = core.attr(ResponseHeader, default=None, kind=core.Kind.array)
-
-    def __init__(
-        self,
-        *,
-        response_code: Union[int, core.IntOut],
-        custom_response_body_key: Optional[Union[str, core.StringOut]] = None,
-        response_header: Optional[
-            Union[List[ResponseHeader], core.ArrayOut[ResponseHeader]]
-        ] = None,
-    ):
-        super().__init__(
-            args=CustomResponse.Args(
-                response_code=response_code,
-                custom_response_body_key=custom_response_body_key,
-                response_header=response_header,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        custom_response_body_key: Optional[Union[str, core.StringOut]] = core.arg(default=None)
-
-        response_code: Union[int, core.IntOut] = core.arg()
-
-        response_header: Optional[
-            Union[List[ResponseHeader], core.ArrayOut[ResponseHeader]]
-        ] = core.arg(default=None)
-
-
-@core.schema
-class Block(core.Schema):
-
-    custom_response: Optional[CustomResponse] = core.attr(CustomResponse, default=None)
-
-    def __init__(
-        self,
-        *,
-        custom_response: Optional[CustomResponse] = None,
-    ):
-        super().__init__(
-            args=Block.Args(
-                custom_response=custom_response,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        custom_response: Optional[CustomResponse] = core.arg(default=None)
-
-
-@core.schema
-class Count(core.Schema):
-
-    custom_request_handling: Optional[CustomRequestHandling] = core.attr(
-        CustomRequestHandling, default=None
-    )
-
-    def __init__(
-        self,
-        *,
-        custom_request_handling: Optional[CustomRequestHandling] = None,
-    ):
-        super().__init__(
-            args=Count.Args(
-                custom_request_handling=custom_request_handling,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        custom_request_handling: Optional[CustomRequestHandling] = core.arg(default=None)
-
-
-@core.schema
-class Action(core.Schema):
-
-    allow: Optional[Allow] = core.attr(Allow, default=None)
-
-    block: Optional[Block] = core.attr(Block, default=None)
-
-    count: Optional[Count] = core.attr(Count, default=None)
-
-    def __init__(
-        self,
-        *,
-        allow: Optional[Allow] = None,
-        block: Optional[Block] = None,
-        count: Optional[Count] = None,
-    ):
-        super().__init__(
-            args=Action.Args(
-                allow=allow,
-                block=block,
-                count=count,
-            ),
-        )
-
-    @core.schema_args
-    class Args(core.SchemaArgs):
-        allow: Optional[Allow] = core.arg(default=None)
-
-        block: Optional[Block] = core.arg(default=None)
-
-        count: Optional[Count] = core.arg(default=None)
+        sampled_requests_enabled: Union[bool, core.BoolOut] = core.arg()
 
 
 @core.schema
